summaryrefslogtreecommitdiff
path: root/android/telephony/PhoneStateListener.java
diff options
context:
space:
mode:
Diffstat (limited to 'android/telephony/PhoneStateListener.java')
-rw-r--r--android/telephony/PhoneStateListener.java4
1 files changed, 2 insertions, 2 deletions
diff --git a/android/telephony/PhoneStateListener.java b/android/telephony/PhoneStateListener.java
index 9ccfa942..c7e51310 100644
--- a/android/telephony/PhoneStateListener.java
+++ b/android/telephony/PhoneStateListener.java
@@ -408,7 +408,7 @@ public class PhoneStateListener {
/**
* Callback invoked when device call state changes.
* @param state call state
* @param incomingNumber incoming call phone number. If application does not have
* {@link android.Manifest.permission#READ_PHONE_STATE READ_PHONE_STATE} permission, an empty
* string will be passed as an argument.
*
@@ -416,7 +416,7 @@ public class PhoneStateListener {
* @see TelephonyManager#CALL_STATE_RINGING
* @see TelephonyManager#CALL_STATE_OFFHOOK
*/
- public void onCallStateChanged(int state, String incomingNumber) {
+ public void onCallStateChanged(int state, String phoneNumber) {
// default implementation empty
}
@@ -408,7 +408,7 @@ public class PhoneStateListener {
* Callback invoked when device call state changes.
* @param state call state
- * @param incomingNumber incoming call phone number. If application does not have
+ * @param phoneNumber call phone number. If application does not have
* {@link android.Manifest.permission#READ_PHONE_STATE READ_PHONE_STATE} permission, an empty
* string will be passed as an argument.